# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.insecureSslTls

Module implementing a check for use of SSL/TLS with insecure protocols.

### Global Attributes

None

### Classes

None

### Functions

checkInsecureSslDefaults | Function to check for SSL use with insecure defaults specified.
checkInsecureSslProtocolVersion | Function to check for use of insecure SSL protocol version.
checkSslWithoutVersion | Function to check for SSL use with no version specified.
getChecks | Public method to get a dictionary with checks handled by this module.

## checkInsecureSslDefaults

checkInsecureSslDefaults(reportError, context, config)

Function to check for SSL use with insecure defaults specified.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## checkInsecureSslProtocolVersion

checkInsecureSslProtocolVersion(reportError, context, config)

Function to check for use of insecure SSL protocol version.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## checkSslWithoutVersion

checkSslWithoutVersion(reportError, context, _config)

Function to check for SSL use with no version specified.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up